==> anonnet-0.0.1-20011112.tgz: anonnet/src/thread.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#include <pthread.h>

#include "common.h"
#include "object.h"


#ifndef __THREAD_H
#define __THREAD_H


typedef void (*thread_main_t)(void*);
typedef void *thread_arg_t;
typedef struct thread thread_t;

typedef thread_t *Thread;

struct thread {
	object_t obj; /* inherit object */

	int		__do_free;
	thread_main_t	__thr_main;
	thread_arg_t	__thr_arg;
	pthread_t	__pthread;
	pthread_attr_t	__pthread_attr;

	char *name;
	int volatile __alive;
};

void *__thread_run(void *);
void __thread_destroy(void *);
void __thread_pre_exec(thread_t *);
void __thread_post_exec(thread_t *);


void thread_init(void *,void (*)(void *),void *);
void thread_destroy(void *);

thread_t *thread_create(void (*)(void *),void *);
void thread_free(thread_t *);

void thread_run(void *);
bool thread_is_alive(void *);

#endif

==> anonnet-0.0.1-20011210.tgz: anonnet/src/thread.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#include <pthread.h>

#include "common.h"
#include "object.h"


#ifndef __THREAD_H
#define __THREAD_H


typedef void (*thread_main_t)(void*);
typedef void *thread_arg_t;
typedef struct thread thread_t;

typedef thread_t *Thread;

struct thread {
	object_t obj; /* inherit object */

	long int	thread_id;
	int		__do_free;
	thread_main_t	__thr_main;
	thread_arg_t	__thr_arg;
	pthread_t	__pthread;
	pthread_attr_t	__pthread_attr;

	char *name;
	int volatile __alive;
};

void *__thread_run(void *);
void __thread_pre_exec(thread_t *);
void __thread_post_exec(thread_t *);


void thread_init(void *,void (*)(void *),void *);
void thread_destroy(void *);

thread_t *thread_create(void (*)(void *),void *);
void thread_free(void *);

void thread_run(void *);
bool thread_is_alive(void *);

#endif /* __THREAD_H */
